==> hudi-0.15.0.src.tgz: hudi-0.15.0/hudi-common/src/main/java/org/apache/hudi/io/storage/HoodieFileWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.io.storage;

import org.apache.avro.Schema;

import org.apache.hudi.common.model.HoodieKey;
import org.apache.hudi.common.model.HoodieRecord;

import java.io.IOException;
import java.util.Properties;

public interface HoodieFileWriter {
  boolean canWrite();

  void writeWithMetadata(HoodieKey key, HoodieRecord record, Schema schema, Properties props) throws IOException;

  void write(String recordKey, HoodieRecord record, Schema schema, Properties props) throws IOException;

  void close() throws IOException;

  default void writeWithMetadata(HoodieKey key, HoodieRecord record, Schema schema) throws IOException {
    writeWithMetadata(key, record, schema, new Properties());
  }

  default void write(String recordKey, HoodieRecord record, Schema schema) throws IOException {
    write(recordKey, record, schema, new Properties());
  }
}

==> hudi-1.0.0.src.tgz: hudi-1.0.0/hudi-common/src/main/java/org/apache/hudi/io/storage/HoodieFileWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.io.storage;

import org.apache.hudi.common.model.HoodieKey;
import org.apache.hudi.common.model.HoodieRecord;

import org.apache.avro.Schema;

import java.io.IOException;
import java.util.Properties;

public interface HoodieFileWriter extends AutoCloseable {
  boolean canWrite();

  void writeWithMetadata(HoodieKey key, HoodieRecord record, Schema schema, Properties props) throws IOException;

  void write(String recordKey, HoodieRecord record, Schema schema, Properties props) throws IOException;

  void close() throws IOException;

  default void writeWithMetadata(HoodieKey key, HoodieRecord record, Schema schema) throws IOException {
    writeWithMetadata(key, record, schema, new Properties());
  }

  default void write(String recordKey, HoodieRecord record, Schema schema) throws IOException {
    write(recordKey, record, schema, new Properties());
  }
}
